==> nextcloud-31.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_reminders/l10n/de.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Dateierinnerungen",
    "Reminder for {name}" : "Erinnerung für {name}",
    "View file" : "Datei anzeigen",
    "View folder" : "Ordner anzeigen",
    "Files reminder" : "Dateierinnerung",
    "This files_reminder can work properly." : "Dieser „files_reminder“ funktioniert ordnungsgemäß.",
    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Die App „files_reminder“ benötigt die Benachrichtigungs-App, um ordnungsgemäß zu funktionieren. Sie sollten entweder Benachrichtigungen aktivieren oder „files_reminder“ deaktivieren.",
    "Set file reminders" : "Dateierinnerungen setzen",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 Dateierinnerungen**\n\nDateierinnerungen festlegen.\n\nHinweis: Um die App ``Dateierinnerungen` zu verwenden, stelle sicher, dass die App `Benachrichtigungen` installiert und aktiviert ist. Die App `Benachrichtigungen` bietet die erforderlichen APIs, damit die App `Dateierinnerungen`ordnungsgemäß funktioniert.",
    "Set reminder for \"{fileName}\"" : "Erinnerung für \"{fileName}\" setzen",
    "Set reminder at custom date & time" : "Erinnerung für benutzerdefinierten Zeitpunkt und Tag erstellen",
    "Clear reminder" : "Erinnerung löschen",
    "Please choose a valid date & time" : "Bitte gültiges Datum und Uhrzeit wählen",
    "Reminder set for \"{fileName}\"" : "Erinnerung für \"{fileName}\" gesetzt",
    "Failed to set reminder" : "Fehler beim Setzen der Erinnerung",
    "Reminder cleared for \"{fileName}\"" : "Erinnerung für \"{fileName}\" gelöscht",
    "Failed to clear reminder" : "Fehler beim Löschen der Erinnerung",
    "We will remind you of this file" : "Du wirst an diese Datei erinnert",
    "Cancel" : "Abbrechen",
    "Set reminder" : "Erinnerung erstellen",
    "Reminder set" : "Erinnerung gesetzt",
    "Set custom reminder" : "Benutzerdefinierte Erinnerung erstellen",
    "Later today" : "Später heute",
    "Set reminder for later today" : "Erinnerung für nachher erstellen",
    "Tomorrow" : "Morgen",
    "Set reminder for tomorrow" : "Erinnerung für morgen erstellen",
    "This weekend" : "Dieses Wochenende",
    "Set reminder for this weekend" : "Erinnerung für dieses Wochenende erstellen",
    "Next week" : "Nächste Woche",
    "Set reminder for next week" : "Erinnerung für nächste Woche erstellen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.9-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_reminders/l10n/de.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Dateierinnerungen",
    "Reminder for {name}" : "Erinnerung für {name}",
    "View file" : "Datei anzeigen",
    "View folder" : "Ordner anzeigen",
    "Files reminder" : "Dateierinnerung",
    "The \"files_reminders\" app can work properly." : "Die App \"files_reminders\" kann ordnungsgemäß funktionieren.",
    "The \"files_reminders\" app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Die App \"files_reminders“ benötigt die Benachrichtigungs-App, um ordnungsgemäß zu funktionieren. Sie sollten entweder Benachrichtigungen aktivieren oder „files_reminders“ deaktivieren.",
    "Set file reminders" : "Dateierinnerungen setzen",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 Dateierinnerungen**\n\nDateierinnerungen festlegen.\n\nHinweis: Um die App ``Dateierinnerungen` zu verwenden, stelle sicher, dass die App `Benachrichtigungen` installiert und aktiviert ist. Die App `Benachrichtigungen` bietet die erforderlichen APIs, damit die App `Dateierinnerungen`ordnungsgemäß funktioniert.",
    "Set reminder for \"{fileName}\"" : "Erinnerung für \"{fileName}\" setzen",
    "Reminder at custom date & time" : "Erinnerung zu benutzerdefiniertem Zeitpunkt und Tag",
    "Clear reminder" : "Erinnerung löschen",
    "Please choose a valid date & time" : "Bitte gültiges Datum und Uhrzeit wählen",
    "Reminder set for \"{fileName}\"" : "Erinnerung für \"{fileName}\" gesetzt",
    "Failed to set reminder" : "Erinnerung konnte nicht festgelegt werden",
    "Reminder cleared for \"{fileName}\"" : "Erinnerung für \"{fileName}\" gelöscht",
    "Failed to clear reminder" : "Erinnerung konnte nicht gelöscht werden",
    "We will remind you of this file" : "Du wirst an diese Datei erinnert",
    "Cancel" : "Abbrechen",
    "Set reminder" : "Erinnerung erstellen",
    "Reminder set" : "Erinnerung gesetzt",
    "Custom reminder" : "Benutzerdefinierte Erinnerung",
    "Later today" : "Später heute",
    "Set reminder for later today" : "Erinnerung für nachher erstellen",
    "Tomorrow" : "Morgen",
    "Set reminder for tomorrow" : "Erinnerung für morgen erstellen",
    "This weekend" : "Dieses Wochenende",
    "Set reminder for this weekend" : "Erinnerung für dieses Wochenende erstellen",
    "Next week" : "Nächste Woche",
    "Set reminder for next week" : "Erinnerung für nächste Woche erstellen",
    "This files_reminder can work properly." : "Dieser „files_reminder“ funktioniert ordnungsgemäß.",
    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Die App „files_reminder“ benötigt die Benachrichtigungs-App, um ordnungsgemäß zu funktionieren. Sie sollten entweder Benachrichtigungen aktivieren oder „files_reminder“ deaktivieren.",
    "Set reminder at custom date & time" : "Erinnerung für benutzerdefinierten Zeitpunkt und Tag erstellen",
    "Set custom reminder" : "Benutzerdefinierte Erinnerung erstellen"
},
"nplurals=2; plural=(n != 1);");
